# Archive Warrior

<div align="center">
  <img src="https://wiki.archiveteam.org/images/e/e0/Warrior-web-screenshot.png" />
</div>

## Descrizione

[![Sito ufficiale](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=firefoxbrowser&style=flat&label=&message=Homepage)](https://warrior.archiveteam.org/) [![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/ArchiveTeam/warrior-dockerfile) [![Docker Hub](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=docker&style=flat&label=&message=Docker Hub)](https://hub.docker.com/r/archiveteam/warrior-dockerfile/)

Archive Warrior è un semplice nodo per aiutare l'[Archive Team](https://archive.org/):

- Con l'uso di pochissime risorse (e un pò di tempo) si può aiutare a salvare un pò di internet
- Chiunque almeno una volta ha usato [web.archive.org](https://web.archive.org/) per (ri)trovare qualcosa

## Struttura file e cartelle

```
/home/
└── docker/
    └── archive-warrior/
        ├── .env
        └── docker-compose.yml
```

- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "2.4"
services:
  archivewarrior:
    container_name: archive-warrior
    image: atdr.meo.ws/archiveteam/warrior-dockerfile
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${ARCWAR_WEBUI_PORT:-8001}:8001
    env_file: .env
    cpus: 2 # usa massimo 2 core del vostro processore
    mem_limit: 2048m # usa massimo 2GB di RAM

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
ARCWAR_WEBUI_PORT=8001

# Archive Warrior
DOWNLOADER=cambiamiperfavore # es. DOWNLOADER=PincoPallino11
WORKER_ID=cambiamiperfavore  #     WORKER_ID=PincoPallino11
SELECTED_PROJECT=auto
CONCURRENT_ITEMS=3
```

## Aggiornamento

### Automatico

Se usate [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose up -d`
2. `docker image prune`

## Backup e ripristino

### Backup

Potete usare [borg](../borg) per fare i backup giornalieri dell'intera cartella `archive-warrior`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

1. fermare il container con `docker-compose down`
2. cancellare l'intera cartella `archive-warrior`
3. dal backup copiare la cartella `archive-warrior`
4. far ripartire il container con `docker-compose up -d`

## Todo

Implementare:

- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
