# Folding@Home

<div align="center">
  <img src="https://www.bleepstatic.com/images/news/software/f/folding-at-home/coronavirus/folding-at-home.jpg" />
</div>

## Descrizione

[![Sito ufficiale](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=firefoxbrowser&style=flat&label=&message=Homepage)](https://foldingathome.org/) [![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/linuxserver/docker-foldingathome) [![Docker Hub](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=docker&style=flat&label=&message=Docker Hub)](https://hub.docker.com/r/linuxserver/foldingathome) [![Docs](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=readthedocs&style=flat&label=&message=Docs)](https://docs.linuxserver.io/images/docker-foldingathome)

Folding@Home è un progetto di calcolo distribuito per aiutare la ricerca medica:

- Simulazione del comportamento delle proteine (e non solo) relative a malattie degenerative, infettive e molto altro
- Supporto al calcolo tramite CPU e/o GPU (la scelta è vostra)

> **P.S è un progetto a cui tengo particolarmente, quindi anche se avete un computer vecchio che non usate, questo è il progetto perfetto per renderlo di nuovo utile a tutti e per tutti**

## Struttura file e cartelle

```
/home/
└── docker/
    └── folding@home/
            ├── config/
            ├── .env
            └── docker-compose.yml
```

- `config/` - cartella dove risiedono i dati che servono a folding@home
- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "3.5"
services:
  fah:
    container_name: linuxserver-fah
    image: lscr.io/linuxserver/foldingathome
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${FAH_WEBUI_PORT:-7396}:7396
    env_file: .env
    volumes:
      - ${FAH_DATA:-/home/docker/folding@home/config}:/config
    healthcheck: # se modificate la porta dell'interfaccia web, ricordatevi di cambiarla anche qua sotto
      test: ["CMD", "curl", "-Ssf", http://localhost:7396"]
      interval: 1m30s
      timeout: 10s
      retries: 3
      start_period: 1m

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
FAH_WEBUI_PORT=7396
FAH_DATA=/home/docker/fah/data

# Folding@Home
TZ=Europe/Amsterdam
```

## Aggiornamento

### Automatico

Usando [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose up -d`
2. `docker image prune`

## Backup e ripristino

### Backup

Usate [borg](../borg) per fare i backup giornalieri dell'intera cartella `folding@home`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

1. fermare il container con `docker-compose down`
2. cancellare l'intera cartella `folding@home`
3. dal backup copiare la cartella `folding@home`
4. far ripartire il container con `docker-compose up -d`

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
