# Komga

<div align="center">
  <img src="https://i.ibb.co/s2JRD9H/komga.png" />
</div>

## Descrizione

[![Sito ufficiale](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=firefoxbrowser&style=flat&label=&message=Homepage)](https://komga.org/) [![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/gotson/komga) [![Docker Hub](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=docker&style=flat&label=&message=Docker Hub)](https://hub.docker.com/r/gotson/komga) [![Docs](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=readthedocs&style=flat&label=&message=Docs)](https://komga.org/guides/) [![Demo](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=jekyll&style=flat&label=&message=Demo)](https://demo.komga.org/ "Login: demo@komga.org | Password: komga-demo") ![RPI Friendly](<https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=raspberrypi&style=flat&label=&message=RPi Friendly>)

Komga è un server per la gestione di manga/comics:

- Lettore web integrato e configurabile
- Organizzare i vostri manga/comics in collezioni
- Modifica e importazione dei metadati, sia locali che integrati
- Multiutente, con possiblità di gestire (anche singolarmente) l'accesso alle librerie
- Compatibile con i classici formati (CBZ, CBR, PDF e EPUB)

## Struttura file e cartelle

```
/home/
└── docker/
    └── komga/
        ├── config/
        ├── data/
        ├── .env
        └── docker-compose.yml
```

- `config/` - cartella dove risiedono i dati che servono a komga
- `data/` - cartella dove vanno messi i manga/comics
- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "3.5"
services:
  komga:
    container_name: komga
    image: gotson/komga
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${KOMGA_WEBUI_PORT:-8080}:8080
    env_file: .env
    volumes:
      - ${KOMGA_CONFIG:-/home/docker/komga/config}:/config
      - ${KOMGA_DATA:-/home/docker/komga/data}:/data

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
KOMGA_WEBUI_PORT=8080
KOMGA_CONFIG=/config
KOMGA_DATA=/data

# Komga
ND_LOGLEVEL=info
```

## Reverse proxy

Vedi [Todo](#Todo)

## Aggiornamento

### Automatico

Usando [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose up -d`
2. `docker image prune`

## Backup e ripristino

### Backup

Usate [borg](../borg) per fare i backup giornalieri dell'intera cartella `komga`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

1. fermare il container con `docker-compose down`
2. cancellare l'intera cartella `komga`
3. dal backup copiare la cartella `komga`
4. far ripartire il container con `docker-compose up -d`

## Todo

Implementare:

- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
