# Transmission

<div align="center">
  <img src="https://transmissionbt.com/images/screenshots/Clutch-Large.jpg" />
</div>

## Descrizione

[![Sito ufficiale](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=firefoxbrowser&style=flat&label=&message=Homepage)](https://transmissionbt.com/) [![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/linuxserver/docker-transmission) [![Docker Hub](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=docker&style=flat&label=&message=Docker Hub)](https://hub.docker.com/r/linuxserver/transmission) [![Docs](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=readthedocs&style=flat&label=&message=Docs)](https://docs.linuxserver.io/images/docker-transmission) ![RPI Friendly](<https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=raspberrypi&style=flat&label=&message=RPi Friendly>)

Transmission è un client BitTorrent open-source e leggero:

- Supporto a varie interfacce web, [Combustion](https://github.com/Secretmapper/combustion), [Transmission Web Control](https://github.com/ronggang/transmission-web-control), [kettu](https://github.com/endor/kettu) e [Flood for Transmission](https://github.com/johman10/flood-for-transmission)
- Supporto a [PHE](https://wikiless.org/wiki/BitTorrent_protocol_encryption), [DHT](https://wikiless.org/wiki/Distributed_hash_table), [µTP](https://wikiless.org/wiki/Micro_Transport_Protocol), [PEX](https://wikiless.org/wiki/Peer_exchange), [LPD](https://wikiless.org/wiki/Local_Peer_Discovery) e [Magnet](https://wikiless.org/wiki/Magnet_URI_scheme)
- Esistono [client](https://transmissionbt.com/resources/) sia ufficiali che di terze parti

## Struttura file e cartelle

```
/home/
└── docker/
    └── transmission/
        ├── config/
        ├── downloads/
        ├── .env
        └── docker-compose.yml
```

- `config/` - cartella dove risiedono i dati che servono a transmission
- `downloads/` - cartella dove vengono scaricati e mantenuti i file relativi ai torrent
- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "3.5"
services:
  transmission:
    container_name: linuxserver-transmission
    image: lscr.io/linuxserver/transmission
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${TRANSMISSION_WEBUI_PORT:-9091}:9091
      - ${TRANSMISSION_EXT_PORT:-51413}:51413/tcp
      - ${TRANSMISSION_EXT_PORT:-51413}:51413/udp
    env_file: .env
    volumes:
      - ${TRANSMISSION_CONFIG:-/home/docker/transmission/config}:/config
      - ${TRANSMISSION_DOWNLOADS:-/home/docker/transmission/downloads}:/downloads

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
TRANSMISSION_CONFIG=/home/docker/transmission/config
TRANSMISSION_DOWNLOADS=/home/docker/transmission/downloads
TRANSMISSION_WEBUI_PORT=9091
TRANSMISSION_EXT_PORT=51413

# transmission
TZ=Europe/Amsterdam
USER=admin
PASS=password
TRANSMISSION_WEB_HOME=/combustion-release/ # scegliere tra /combustion-release/, /transmission-web-control/, /kettu/ o /flood-for-transmission/
```

# Reverse proxy

Vedi [Todo](#Todo)

# Aggiornamento

### Automatico

Usando [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose pull`
2. `docker-compose up -d`
3. `docker image prune`

## Backup e ripristino

### Backup

Usate [borg](../borg) per fare i backup giornalieri dell'intera cartella `transmission`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

- fermare il container con `docker-compose down`
- cancellare l'intera cartella `transmission`
- dal backup copiare la cartella `transmission`
- far ripartire il container con `docker-compose up -d`

## Todo

Implementare:

- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**
- vpn: **[wireguard](https://www.wireguard.com/)**

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
