# Tubesync

<div align="center">
  <img src="https://raw.githubusercontent.com/meeb/tubesync/main/docs/dashboard-v0.5.png" />
</div>

## Descrizione

[![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/meeb/tubesync)

Tubesync è un PVR (personal video recorder) per YouTube:

- Praticamente potete gestire tutto tramite l'interefaccia web
- Supporto completo per i canali (anche tramite ID) e le playlist
- [yt-dlp](https://github.com/yt-dlp/yt-dlp) integrato e aggiornato di frequente

## Struttura file e cartelle

```
/home/
└── docker/
    └── tubesync/
        ├── config/
        ├── downloads/
        ├── .env
        └── docker-compose.yml
```

- `config/` - cartella dove risiedono i dati che servono a tubesync
- `downloads/` - cartella dove vengono salvati i video
- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "3.5"
services:
  tubesync:
    container_name: tubesync
    image: ghcr.io/meeb/tubesync
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${TUBESYNC_WEBUI_PORT:-4848}:4848
    env_file: .env
    volumes:
      - ${TUBESYNC_CONFIG:-/home/docker/tubesync/config}:/config
      - ${TUBESYNC_DOWNLOADS:-/home/docker/tubesync/downloads}:/downloads

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
TUBESYNC_WEBUI_PORT=4848
TUBESYNC_CONFIG=/home/docker/tubesync/config
TUBESYNC_DOWNLOADS=/home/docker/tubesync/downloads

# Tubesync
TZ=Europe/Amsterdam
```

## Reverse proxy

Vedi [Todo](#Todo)

## Aggiornamento

### Automatico

Usando [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose up -d`
2. `docker image prune`

## Backup e ripristino

### Backup

Usate [borg](../borg) per fare i backup giornalieri dell'intera cartella `tubesync`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

1. fermare il container con `docker-compose down`
2. cancellare l'intera cartella `tubesync`
3. dal backup copiare la cartella `tubesync`
4. far ripartire il container con `docker-compose up -d`

## Todo

Implementare:

- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
