# Unifi Controller

<div align="center">
  <img src="https://i.ibb.co/W3CMvL4/unifi.png" />
</div>

## Descrizione

[![Sito ufficiale](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=firefoxbrowser&style=flat&label=&message=Homepage)](https://www.ui.com/software/) [![Sorgente](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=github&style=flat&label=&message=Sorgente)](https://github.com/linuxserver/docker-unifi-controller) [![Docker Hub](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=docker&style=flat&label=&message=Docker Hub)](https://hub.docker.com/r/linuxserver/unifi-controller) [![Docs](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=readthedocs&style=flat&label=&message=Docs)](https://docs.linuxserver.io/images/docker-unifi-controller) [![Demo](https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=jekyll&style=flat&label=&message=Demo)](https://demo.ui.com/manage/site/default/dashboard) ![RPI Friendly](<https://img.shields.io/static/v1.svg?color=555555&logoColor=ffffff&logo=raspberrypi&style=flat&label=&message=RPi Friendly>)

Unfi Controller è un controller per la gestione dell'hardware Ubiquiti:

- Gestione di tutto solo tramite interfaccia web
- Aggiornare, configurare e personalizzare tutto l'hardware compatibile
- Backup della configurazione, sia del controller che dell'hardware

## Struttura file e cartelle

```
/home/
└── docker/
    └── unifi-controller/
        ├── config/
        ├── .env
        └── docker-compose.yml
```

- `config/` - cartella dove risiedono i dati che servono a unifi
- `.env` - file contenenti le variabili environment per il docker-compose
- `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano**

## Esempi

Semplice esempio per iniziare ad usare subito il container

### network

Con docker

```bash
docker network create custom-bridge
```

oppure usando podman

```bash
podman network create custom-bridge
```

### docker-compose

`docker-compose.yml`

```yml
version: "3.5"
services:
  unifi:
    container_name: linuxserver-unifi-controller
    image: lscr.io/linuxserver/unifi-controller
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${UNIFI_STUN_PORT:-3478}:3478/udp
      - ${UNIFI_WEBUI_PORT:-8080}:8080
      - ${UNIFI_HTTPS_PORT:-8443}:8443
      - ${UNIFI_AP_DSV_PORT:-10001}:10001/udp
    env_file: .env
    volumes:
      - ${UNIFI_CONFIG:-/home/docker/unifi-controller/config}:/config

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`

```bash
# Generale
UNIFI_STUN_PORT=3478
UNIFI_WEBUI_PORT=8080
UNIFI_HTTPS_PORT=8443
UNIFI_AP_DSV_PORT=10001
UNIFI_CONFIG=/config

# Unifi
MEM_LIMIT=1024M # opzionale, di base è un 1 GB di ram massima allocata
```

## Reverse proxy

Vedi [Todo](#Todo)

## Aggiornamento

### Automatico

Se usate [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale

1. `docker-compose pull`
2. `docker-compose up -d`
3. `docker image prune`

## Backup e ripristino

### Backup

Usado [borg](../borg) per fare i backup giornalieri dell'intera cartella `unifi`

### Ripristino

Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg#user-content-controllare-la-cartella-dei-backup)

1. fermare il container con `docker-compose down`
2. cancellare l'intera cartella `unifi-controller`
3. dal backup copiare la cartella `unifi-controller`
4. far ripartire il container con `docker-compose up -d`

## Todo

Implementare:

- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**

---

Licenza: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt)
